read_server_config_legacy_encrypted

Function read_server_config_legacy_encrypted 

fn read_server_config_legacy_encrypted(path: &Path) -> Result<ServerConfig>
Reads the server config with the legacy encrypted private config format, using the password from the password.private file.