pub fn read_server_config(path: &Path) -> Result<ServerConfig>Expand description
Reads the server config from plaintext JSON files. Falls back to reading the legacy encrypted format using the password.private file if the plaintext private config does not exist.